[llvm] r188876 - MC CFG: Add more MCFunction container methods (find, empty).

Ahmed Bougacha ahmed.bougacha at gmail.com
Wed Aug 21 00:27:59 PDT 2013


Author: ab
Date: Wed Aug 21 02:27:59 2013
New Revision: 188876

URL: http://llvm.org/viewvc/llvm-project?rev=188876&view=rev
Log:
MC CFG: Add more MCFunction container methods (find, empty).

Modified:
    llvm/trunk/include/llvm/MC/MCFunction.h
    llvm/trunk/lib/MC/MCFunction.cpp

Modified: llvm/trunk/include/llvm/MC/MCFunction.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/MC/MCFunction.h?rev=188876&r1=188875&r2=188876&view=diff
==============================================================================
--- llvm/trunk/lib/MC/MCFunction.cpp (original)
+++ llvm/trunk/lib/MC/MCFunction.cpp Wed Aug 21 02:27:59 2013
@@ -30,6 +30,18 @@ MCBasicBlock &MCFunction::createBlock(co
   return *Blocks.back();
 }
 
+const MCBasicBlock *MCFunction::find(uint64_t StartAddr) const {
+  for (const_iterator I = begin(), E = end(); I != E; ++I)
+    if ((*I)->getInsts()->getBeginAddr() == StartAddr)
+      return (*I);
+  return 0;
+}
+
+MCBasicBlock *MCFunction::find(uint64_t StartAddr) {
+  return const_cast<MCBasicBlock *>(
+           const_cast<const MCFunction *>(this)->find(StartAddr));
+}
+
 // MCBasicBlock
 
 MCBasicBlock::MCBasicBlock(const MCTextAtom &Insts, MCFunction *Parent)





More information about the llvm-commits mailing list
--- llvm/trunk/include/llvm/MC/MCFunction.h (original)
+++ llvm/trunk/include/llvm/MC/MCFunction.h Wed Aug 21 02:27:59 2013
@@ -97,13 +97,15 @@ public:
 
   StringRef getName() const { return Name; }
 
   /// \name Access to the function's basic blocks. No ordering is enforced.
   /// @{
   /// \brief Get the entry point basic block.
   const MCBasicBlock *getEntryBlock() const { return front(); }
         MCBasicBlock *getEntryBlock()       { return front(); }
 
-  // NOTE: Dereferencing iterators gives pointers, so maybe a list is best here.
+  bool empty() const { return Blocks.empty(); }
+
   typedef BasicBlockListTy::const_iterator const_iterator;
   typedef BasicBlockListTy::      iterator       iterator;
   const_iterator begin() const { return Blocks.begin(); }
@@ -115,6 +117,10 @@ public:
         MCBasicBlock* front()       { return Blocks.front(); }
   const MCBasicBlock*  back() const { return Blocks.back(); }
         MCBasicBlock*  back()       { return Blocks.back(); }
+
+  /// \brief Find the basic block, if any, that starts at \p StartAddr.
+  const MCBasicBlock *find(uint64_t StartAddr) const;
+        MCBasicBlock *find(uint64_t StartAddr);
   /// @}
 };
 
@@ -97,13 +97,15 @@ public:
   StringRef getName() const { return Name; }
 
-  /// \name Access to the function's basic blocks. No ordering is enforced.
+  /// \name Access to the function's basic blocks. No ordering is enforced,
+  /// except that the first block is the entry block.
   /// @{
   /// \brief Get the entry point basic block.

Modified: llvm/trunk/lib/MC/MCFunction.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/MC/MCFunction.cpp?rev=188876&r1=188875&r2=188876&view=diff
==============================================================================